"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.computeHash = exports.ComputeSchema = exports.GPUComputeSchema = exports.PerformanceCPUComputeSchema = exports.SharedCPUComputeSchema = void 0;
const data_contracts_1 = require("../../rest/generated/cloud/data-contracts");
const crypto_1 = require("crypto");
const zod_1 = require("zod");
const BaseComputeSchema = zod_1.z.object({
    pool: zod_1.z.string().default('default').optional().describe('The name of the compute pool to use'),
    numReplicas: zod_1.z
        .number()
        .int()
        .min(0, { message: 'Must be at least 0' })
        .max(1000, { message: 'Must be at most 1000' })
        .default(1)
        .describe('The number of replicas'),
    regions: zod_1.z
        .array(zod_1.z.nativeEnum(data_contracts_1.ManagedWorkerRegion))
        .optional()
        .describe('The regions to deploy the worker to'),
    cpus: zod_1.z
        .number()
        .int()
        .min(1, { message: 'Must be at least 1' })
        .max(64, { message: 'Must be at most 64' })
        .describe('The number of CPUs to use for the worker'),
});
exports.SharedCPUComputeSchema = BaseComputeSchema.extend({
    cpuKind: zod_1.z.literal('shared'),
    memoryMb: zod_1.z
        .number()
        .int()
        .min(256, { message: 'Must be at least 256 MB' })
        .max(65536, { message: 'Must be at most 65536 MB' })
        .refine((val) => val % 256 === 0, { message: 'Must be divisible by 256 MB' })
        .describe('The amount of memory in MB to use for the worker'),
});
exports.PerformanceCPUComputeSchema = BaseComputeSchema.extend({
    cpuKind: zod_1.z.literal('performance'),
    memoryMb: zod_1.z
        .number()
        .int()
        .min(2048, { message: 'Must be at least 1024 MB' })
        .max(65536, { message: 'Must be at most 65536 MB' })
        .refine((val) => val % 256 === 0, { message: 'Must be divisible by 256 MB' })
        .describe('The amount of memory in MB to use for the worker'),
});
// eslint-disable-next-line no-shadow
const AllowedGPUManagedWorkerRegions = [data_contracts_1.ManagedWorkerRegion.Ord];
exports.GPUComputeSchema = BaseComputeSchema.extend({
    cpuKind: zod_1.z.literal('shared'),
    gpuKind: zod_1.z.enum(['a10', 'l40s', 'a100-40gb', 'a100-80gb']),
    regions: zod_1.z
        .array(zod_1.z.nativeEnum(data_contracts_1.ManagedWorkerRegion))
        .refine((val) => val.every((region) => AllowedGPUManagedWorkerRegions.includes(region)), {
        message: 'Invalid GPU region',
    })
        .optional()
        .describe('The regions to deploy the worker to'),
    memoryMb: zod_1.z
        .number()
        .int()
        .min(2048, { message: 'Must be at least 1024 MB' })
        .max(65536, { message: 'Must be at most 65536 MB' })
        .refine((val) => val % 256 === 0, { message: 'Must be divisible by 256 MB' })
        .describe('The amount of memory in MB to use for the worker'),
});
exports.ComputeSchema = zod_1.z.union([
    exports.SharedCPUComputeSchema,
    exports.PerformanceCPUComputeSchema,
    exports.GPUComputeSchema,
]);
const computeHash = (compute) => {
    const str = JSON.stringify(compute);
    return (0, crypto_1.createHash)('sha256').update(str).digest('hex');
};
exports.computeHash = computeHash;
