"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ManagedCompute = void 0;
const logger_1 = require("../../../util/logger");
const compute_config_1 = require("./compute-config");
class ManagedCompute {
    constructor(actions, client, maxRuns = 1) {
        this.actions = actions;
        this.client = client;
        this.maxRuns = maxRuns;
        this.configs = this.getComputeConfigs(this.actions);
        this.cloudRegisterId = this.client.config.cloud_register_id;
        this.logger = new logger_1.Logger(`Compute`, this.client.config.log_level);
        if (this.configs.length === 0) {
            this.logger.debug('No compute configs found, skipping cloud registration and running all actions locally.');
            return;
        }
        if (!this.cloudRegisterId) {
            this.logger.warn('Managed cloud compute plan:');
            this.configs.forEach((compute) => {
                var _a;
                this.logger.warn('    ----------------------------');
                this.logger.warn(`    actions: ${(_a = compute.actions) === null || _a === void 0 ? void 0 : _a.join(', ')}`);
                this.logger.warn(`    num replicas: ${compute.numReplicas}`);
                this.logger.warn(`    cpu kind: ${compute.cpuKind}`);
                this.logger.warn(`    cpus: ${compute.cpus}`);
                this.logger.warn(`    memory mb: ${compute.memoryMb}`);
                // this.logger.warn(`    regions: ${compute.regions?.join(', ')}`);
            });
            this.logger.warn('NOTICE: local mode detected, skipping cloud registration and running all actions locally.');
        }
    }
    getComputeConfigs(actions) {
        /**
         * Builds a map of compute hashes to compute configs and lists of actions that correspond to each compute hash.
         */
        const computeMap = {};
        try {
            Object.entries(actions).forEach(([action, { compute }]) => {
                if (!compute) {
                    return;
                }
                const key = (0, compute_config_1.computeHash)(compute);
                if (!computeMap[key]) {
                    computeMap[key] = {
                        actions: [],
                        numReplicas: compute.numReplicas,
                        cpuKind: compute.cpuKind,
                        cpus: compute.cpus,
                        memoryMb: compute.memoryMb,
                        regions: compute.regions,
                        slots: this.maxRuns,
                    };
                }
                computeMap[key].actions.push(action);
            });
            return Object.values(computeMap);
        }
        catch (e) {
            this.logger.error(`Error getting compute configs: ${e}`);
            return [];
        }
    }
    cloudRegister() {
        return __awaiter(this, void 0, void 0, function* () {
            /**
             * Registers the compute plan with the cloud if the environment variable is set.
             * Exits the process upon completion.
             */
            if (this.cloudRegisterId) {
                this.logger.info(`Registering cloud compute plan with ID: ${this.cloudRegisterId}`);
                try {
                    if (this.configs.length === 0) {
                        this.logger.warn('No actions to register, skipping cloud registration.');
                        process.exit(0);
                    }
                    const req = {
                        runtimeConfigs: this.configs,
                    };
                    yield this.client.cloudApi.infraAsCodeCreate(this.cloudRegisterId, req);
                    process.exit(0);
                }
                catch (e) {
                    this.logger.error(`ERROR: ${e}`);
                    process.exit(1);
                }
            }
        });
    }
}
exports.ManagedCompute = ManagedCompute;
